{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.AutoRental where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AutomotiveBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AutoRental
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place

-- | A car rental business.
--
--   [@id@] AutoRental
--
--   [@label@] Auto Rental
--
--   [@comment@] A car rental business.
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','AutomotiveBusiness','AutoRental','Thing','Place','LocalBusiness','AutomotiveBusiness'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'AutomotiveBusiness'@
--
--   [@url@] <http://schema.org/AutoRental>
data AutoRental = AutoRental { branchCode :: BranchCode
                             , currenciesAccepted :: CurrenciesAccepted
                             , openingHours :: OpeningHours
                             , paymentAccepted :: PaymentAccepted
                             , priceRange :: PriceRange
                             , address :: Address
                             , aggregateRating :: AggregateRating
                             , alumni :: Alumni
                             , areaServed :: AreaServed
                             , award :: Award
                             , brand :: Brand
                             , contactPoint :: ContactPoint
                             , department :: Department
                             , dissolutionDate :: DissolutionDate
                             , duns :: Duns
                             , email :: Email
                             , employee :: Employee
                             , event :: Event
                             , faxNumber :: FaxNumber
                             , founder :: Founder
                             , foundingDate :: FoundingDate
                             , foundingLocation :: FoundingLocation
                             , globalLocationNumber :: GlobalLocationNumber
                             , hasOfferCatalog :: HasOfferCatalog
                             , hasPOS :: HasPOS
                             , isicV4 :: IsicV4
                             , legalName :: LegalName
                             , location :: Location
                             , logo :: Logo
                             , makesOffer :: MakesOffer
                             , member :: Member
                             , memberOf :: MemberOf
                             , naics :: Naics
                             , numberOfEmployees :: NumberOfEmployees
                             , owns :: Owns
                             , parentOrganization :: ParentOrganization
                             , review :: Review
                             , seeks :: Seeks
                             , subOrganization :: SubOrganization
                             , taxID :: TaxID
                             , telephone :: Telephone
                             , vatID :: VatID
                             , additionalProperty :: AdditionalProperty
                             , containedInPlace :: ContainedInPlace
                             , containsPlace :: ContainsPlace
                             , geo :: Geo
                             , hasMap :: HasMap
                             , openingHoursSpecification :: OpeningHoursSpecification
                             , photo :: Photo
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData AutoRental where
  _label         = const "Auto Rental"
  _comment_plain = const "A car rental business."
  _comment       = const "A car rental business."
  _url           = const "http://schema.org/AutoRental"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AutomotiveBusiness.AutomotiveBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AutoRental.AutoRental)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AutomotiveBusiness.AutomotiveBusiness)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AutomotiveBusiness.AutomotiveBusiness)]