{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ChooseAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AssessAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.VoteAction

-- | The act of expressing a preference from a set of options or a large or unbounded set of choices/options.
--
--   [@id@] ChooseAction
--
--   [@label@] Choose Action
--
--   [@comment@] The act of expressing a preference from a set of options or a large or unbounded set of choices/options.
--
--   [@ancestors@] @'Thing','Action','AssessAction'@
--
--   [@subtypes@] @'VoteAction'@
--
--   [@supertypes@] @'AssessAction'@
--
--   [@url@] <http://schema.org/ChooseAction>
data ChooseAction = ChooseAction { actionOption :: ActionOption
                                 , actionStatus :: ActionStatus
                                 , agent :: Agent
                                 , endTime :: EndTime
                                 , error :: Error
                                 , instrument :: Instrument
                                 , location :: Location
                                 , object :: Object
                                 , participant :: Participant
                                 , result :: Result
                                 , startTime :: StartTime
                                 , target :: Target
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData ChooseAction where
  _label         = const "Choose Action"
  _comment_plain = const "The act of expressing a preference from a set of options or a large or unbounded set of choices/options."
  _comment       = const "The act of expressing a preference from a set of options or a large or unbounded set of choices/options."
  _url           = const "http://schema.org/ChooseAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AssessAction.AssessAction)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.VoteAction.VoteAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AssessAction.AssessAction)]