{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.DonateAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TradeAction

-- | The act of providing goods, services, or money without compensation, often for philanthropic reasons.
--
--   [@id@] DonateAction
--
--   [@label@] Donate Action
--
--   [@comment@] The act of providing goods, services, or money without compensation, often for philanthropic reasons.
--
--   [@ancestors@] @'Thing','Action','TradeAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'TradeAction'@
--
--   [@url@] <http://schema.org/DonateAction>
data DonateAction = DonateAction { recipient :: Recipient
                                 , price :: Price
                                 , priceSpecification :: PriceSpecification
                                 , actionStatus :: ActionStatus
                                 , agent :: Agent
                                 , endTime :: EndTime
                                 , error :: Error
                                 , instrument :: Instrument
                                 , location :: Location
                                 , object :: Object
                                 , participant :: Participant
                                 , result :: Result
                                 , startTime :: StartTime
                                 , target :: Target
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData DonateAction where
  _label         = const "Donate Action"
  _comment_plain = const "The act of providing goods, services, or money without compensation, often for philanthropic reasons."
  _comment       = const "The act of providing goods, services, or money without compensation, often for philanthropic reasons."
  _url           = const "http://schema.org/DonateAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TradeAction.TradeAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.TradeAction.TradeAction)]