{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.EntryPoint where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | An entry point, within some Web-based protocol.
--
--   [@id@] EntryPoint
--
--   [@label@] Entry Point
--
--   [@comment@] An entry point, within some Web-based protocol.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/EntryPoint>
data EntryPoint = EntryPoint { actionApplication :: ActionApplication
                             , actionPlatform :: ActionPlatform
                             , contentType :: ContentType
                             , encodingType :: EncodingType
                             , httpMethod :: HttpMethod
                             , urlTemplate :: UrlTemplate
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData EntryPoint where
  _label         = const "Entry Point"
  _comment_plain = const "An entry point, within some Web-based protocol."
  _comment       = const "An entry point, within some Web-based protocol."
  _url           = const "http://schema.org/EntryPoint"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]