{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Flight where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | An airline flight.
--
--   [@id@] Flight
--
--   [@label@] Flight
--
--   [@comment@] An airline flight.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/Flight>
data Flight = Flight { aircraft :: Aircraft
                     , arrivalAirport :: ArrivalAirport
                     , arrivalGate :: ArrivalGate
                     , arrivalTerminal :: ArrivalTerminal
                     , arrivalTime :: ArrivalTime
                     , boardingPolicy :: BoardingPolicy
                     , departureAirport :: DepartureAirport
                     , departureGate :: DepartureGate
                     , departureTerminal :: DepartureTerminal
                     , departureTime :: DepartureTime
                     , estimatedFlightDuration :: EstimatedFlightDuration
                     , flightDistance :: FlightDistance
                     , flightNumber :: FlightNumber
                     , mealService :: MealService
                     , provider :: Provider
                     , seller :: Seller
                     , webCheckinTime :: WebCheckinTime
                     , additionalType :: AdditionalType
                     , alternateName :: AlternateName
                     , description :: Description
                     , image :: Image
                     , mainEntityOfPage :: MainEntityOfPage
                     , name :: Name
                     , potentialAction :: PotentialAction
                     , sameAs :: SameAs
                     , url :: Url
                     }
              deriving (Show, Read, Eq, Typeable)

instance MetaData Flight where
  _label         = const "Flight"
  _comment_plain = const "An airline flight."
  _comment       = const "An airline flight."
  _url           = const "http://schema.org/Flight"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]