{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.HVACBusiness where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.HomeAndConstructionBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.HVACBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place

-- | A business that provide Heating, Ventilation and Air Conditioning services.
--
--   [@id@] HVACBusiness
--
--   [@label@] HVAC Business
--
--   [@comment@] A business that provide Heating, Ventilation and Air Conditioning services.
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','HomeAndConstructionBusiness','HVACBusiness','Thing','Place','LocalBusiness','HomeAndConstructionBusiness'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'HomeAndConstructionBusiness'@
--
--   [@url@] <http://schema.org/HVACBusiness>
data HVACBusiness = HVACBusiness { branchCode :: BranchCode
                                 , currenciesAccepted :: CurrenciesAccepted
                                 , openingHours :: OpeningHours
                                 , paymentAccepted :: PaymentAccepted
                                 , priceRange :: PriceRange
                                 , address :: Address
                                 , aggregateRating :: AggregateRating
                                 , alumni :: Alumni
                                 , areaServed :: AreaServed
                                 , award :: Award
                                 , brand :: Brand
                                 , contactPoint :: ContactPoint
                                 , department :: Department
                                 , dissolutionDate :: DissolutionDate
                                 , duns :: Duns
                                 , email :: Email
                                 , employee :: Employee
                                 , event :: Event
                                 , faxNumber :: FaxNumber
                                 , founder :: Founder
                                 , foundingDate :: FoundingDate
                                 , foundingLocation :: FoundingLocation
                                 , globalLocationNumber :: GlobalLocationNumber
                                 , hasOfferCatalog :: HasOfferCatalog
                                 , hasPOS :: HasPOS
                                 , isicV4 :: IsicV4
                                 , legalName :: LegalName
                                 , location :: Location
                                 , logo :: Logo
                                 , makesOffer :: MakesOffer
                                 , member :: Member
                                 , memberOf :: MemberOf
                                 , naics :: Naics
                                 , numberOfEmployees :: NumberOfEmployees
                                 , owns :: Owns
                                 , parentOrganization :: ParentOrganization
                                 , review :: Review
                                 , seeks :: Seeks
                                 , subOrganization :: SubOrganization
                                 , taxID :: TaxID
                                 , telephone :: Telephone
                                 , vatID :: VatID
                                 , additionalProperty :: AdditionalProperty
                                 , containedInPlace :: ContainedInPlace
                                 , containsPlace :: ContainsPlace
                                 , geo :: Geo
                                 , hasMap :: HasMap
                                 , openingHoursSpecification :: OpeningHoursSpecification
                                 , photo :: Photo
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData HVACBusiness where
  _label         = const "HVAC Business"
  _comment_plain = const "A business that provide Heating, Ventilation and Air Conditioning services."
  _comment       = const "A business that provide Heating, Ventilation and Air Conditioning services."
  _url           = const "http://schema.org/HVACBusiness"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.HomeAndConstructionBusiness.HomeAndConstructionBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.HVACBusiness.HVACBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.HomeAndConstructionBusiness.HomeAndConstructionBusiness)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.HomeAndConstructionBusiness.HomeAndConstructionBusiness)]