{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ItemList where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BreadcrumbList
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.OfferCatalog

-- | A list of items of any sort—for example, Top 10 Movies About Weathermen, or Top 100 Party Songs. Not to be confused with HTML lists, which are often used only for formatting.
--
--   [@id@] ItemList
--
--   [@label@] Item List
--
--   [@comment@] A list of items of any sort—for example, Top 10 Movies About Weathermen, or Top 100 Party Songs. Not to be confused with HTML lists, which are often used only for formatting.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@] @'BreadcrumbList','OfferCatalog'@
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/ItemList>
data ItemList = ItemList { itemListElement :: ItemListElement
                         , itemListOrder :: ItemListOrder
                         , numberOfItems :: NumberOfItems
                         , additionalType :: AdditionalType
                         , alternateName :: AlternateName
                         , description :: Description
                         , image :: Image
                         , mainEntityOfPage :: MainEntityOfPage
                         , name :: Name
                         , potentialAction :: PotentialAction
                         , sameAs :: SameAs
                         , url :: Url
                         }
                deriving (Show, Read, Eq, Typeable)

instance MetaData ItemList where
  _label         = const "Item List"
  _comment_plain = const "A list of items of any sort—for example, Top 10 Movies About Weathermen, or Top 100 Party Songs. Not to be confused with HTML lists, which are often used only for formatting."
  _comment       = const "A list of items of any sort—for example, Top 10 Movies About Weathermen, or Top 100 Party Songs. Not to be confused with HTML lists, which are often used only for formatting."
  _url           = const "http://schema.org/ItemList"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.BreadcrumbList.BreadcrumbList)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.OfferCatalog.OfferCatalog)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]