{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Joint where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AnatomicalStructure

-- | The anatomical location at which two or more bones make contact.
--
--   [@id@] Joint
--
--   [@label@] Joint
--
--   [@comment@] The anatomical location at which two or more bones make contact.
--
--   [@ancestors@] @'Thing','MedicalEntity','AnatomicalStructure'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'AnatomicalStructure'@
--
--   [@url@] <http://schema.org/Joint>
data Joint = Joint { biomechnicalClass :: BiomechnicalClass
                   , functionalClass :: FunctionalClass
                   , structuralClass :: StructuralClass
                   , associatedPathophysiology :: AssociatedPathophysiology
                   , bodyLocation :: BodyLocation
                   , connectedTo :: ConnectedTo
                   , diagram :: Diagram
                   , function :: Function
                   , partOfSystem :: PartOfSystem
                   , relatedCondition :: RelatedCondition
                   , relatedTherapy :: RelatedTherapy
                   , subStructure :: SubStructure
                   , code :: Code
                   , guideline :: Guideline
                   , medicineSystem :: MedicineSystem
                   , recognizingAuthority :: RecognizingAuthority
                   , relevantSpecialty :: RelevantSpecialty
                   , study :: Study
                   , additionalType :: AdditionalType
                   , alternateName :: AlternateName
                   , description :: Description
                   , image :: Image
                   , mainEntityOfPage :: MainEntityOfPage
                   , name :: Name
                   , potentialAction :: PotentialAction
                   , sameAs :: SameAs
                   , url :: Url
                   }
             deriving (Show, Read, Eq, Typeable)

instance MetaData Joint where
  _label         = const "Joint"
  _comment_plain = const "The anatomical location at which two or more bones make contact."
  _comment       = const "The anatomical location at which two or more bones make contact."
  _url           = const "http://schema.org/Joint"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AnatomicalStructure.AnatomicalStructure)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AnatomicalStructure.AnatomicalStructure)]