{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.MoveAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ArriveAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DepartAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TravelAction

-- | The act of an agent relocating to a place.Related actions:TransferAction: Unlike TransferAction, the subject of the move is a living Person or Organization rather than an inanimate object.
--
--   [@id@] MoveAction
--
--   [@label@] Move Action
--
--   [@comment@] The act of an agent relocating to a place.<p>Related actions:</p><ul><li><a href=\"http://schema.org/TransferAction\">TransferAction</a>: Unlike TransferAction, the subject of the move is a living Person or Organization rather than an inanimate object</li></ul>.
--
--   [@ancestors@] @'Thing','Action'@
--
--   [@subtypes@] @'ArriveAction','DepartAction','TravelAction'@
--
--   [@supertypes@] @'Action'@
--
--   [@url@] <http://schema.org/MoveAction>
data MoveAction = MoveAction { fromLocation :: FromLocation
                             , toLocation :: ToLocation
                             , actionStatus :: ActionStatus
                             , agent :: Agent
                             , endTime :: EndTime
                             , error :: Error
                             , instrument :: Instrument
                             , location :: Location
                             , object :: Object
                             , participant :: Participant
                             , result :: Result
                             , startTime :: StartTime
                             , target :: Target
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData MoveAction where
  _label         = const "Move Action"
  _comment_plain = const "The act of an agent relocating to a place.Related actions:TransferAction: Unlike TransferAction, the subject of the move is a living Person or Organization rather than an inanimate object."
  _comment       = const "The act of an agent relocating to a place.<p>Related actions:</p><ul><li><a href=\"http://schema.org/TransferAction\">TransferAction</a>: Unlike TransferAction, the subject of the move is a living Person or Organization rather than an inanimate object</li></ul>."
  _url           = const "http://schema.org/MoveAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ArriveAction.ArriveAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.DepartAction.DepartAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TravelAction.TravelAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]