{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Nerve where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type hiding (Nerve)
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AnatomicalStructure

-- | A common pathway for the electrochemical nerve impulses that are transmitted along each of the axons.
--
--   [@id@] Nerve
--
--   [@label@] Nerve
--
--   [@comment@] A common pathway for the electrochemical nerve impulses that are transmitted along each of the axons.
--
--   [@ancestors@] @'Thing','MedicalEntity','AnatomicalStructure'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'AnatomicalStructure'@
--
--   [@url@] <http://schema.org/Nerve>
data Nerve = Nerve { branch :: Branch
                   , nerveMotor :: NerveMotor
                   , sensoryUnit :: SensoryUnit
                   , sourcedFrom :: SourcedFrom
                   , associatedPathophysiology :: AssociatedPathophysiology
                   , bodyLocation :: BodyLocation
                   , connectedTo :: ConnectedTo
                   , diagram :: Diagram
                   , function :: Function
                   , partOfSystem :: PartOfSystem
                   , relatedCondition :: RelatedCondition
                   , relatedTherapy :: RelatedTherapy
                   , subStructure :: SubStructure
                   , code :: Code
                   , guideline :: Guideline
                   , medicineSystem :: MedicineSystem
                   , recognizingAuthority :: RecognizingAuthority
                   , relevantSpecialty :: RelevantSpecialty
                   , study :: Study
                   , additionalType :: AdditionalType
                   , alternateName :: AlternateName
                   , description :: Description
                   , image :: Image
                   , mainEntityOfPage :: MainEntityOfPage
                   , name :: Name
                   , potentialAction :: PotentialAction
                   , sameAs :: SameAs
                   , url :: Url
                   }
             deriving (Show, Read, Eq, Typeable)

instance MetaData Nerve where
  _label         = const "Nerve"
  _comment_plain = const "A common pathway for the electrochemical nerve impulses that are transmitted along each of the axons."
  _comment       = const "A common pathway for the electrochemical nerve impulses that are transmitted along each of the axons."
  _url           = const "http://schema.org/Nerve"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AnatomicalStructure.AnatomicalStructure)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AnatomicalStructure.AnatomicalStructure)]