{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ParcelDelivery where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | The delivery of a parcel either via the postal service or a commercial service.
--
--   [@id@] ParcelDelivery
--
--   [@label@] Parcel Delivery
--
--   [@comment@] The delivery of a parcel either via the postal service or a commercial service.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/ParcelDelivery>
data ParcelDelivery = ParcelDelivery { deliveryAddress :: DeliveryAddress
                                     , deliveryStatus :: DeliveryStatus
                                     , expectedArrivalFrom :: ExpectedArrivalFrom
                                     , expectedArrivalUntil :: ExpectedArrivalUntil
                                     , hasDeliveryMethod :: HasDeliveryMethod
                                     , itemShipped :: ItemShipped
                                     , originAddress :: OriginAddress
                                     , partOfOrder :: PartOfOrder
                                     , provider :: Provider
                                     , trackingNumber :: TrackingNumber
                                     , trackingUrl :: TrackingUrl
                                     , additionalType :: AdditionalType
                                     , alternateName :: AlternateName
                                     , description :: Description
                                     , image :: Image
                                     , mainEntityOfPage :: MainEntityOfPage
                                     , name :: Name
                                     , potentialAction :: PotentialAction
                                     , sameAs :: SameAs
                                     , url :: Url
                                     }
                      deriving (Show, Read, Eq, Typeable)

instance MetaData ParcelDelivery where
  _label         = const "Parcel Delivery"
  _comment_plain = const "The delivery of a parcel either via the postal service or a commercial service."
  _comment       = const "The delivery of a parcel either via the postal service or a commercial service."
  _url           = const "http://schema.org/ParcelDelivery"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]