{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.PaymentChargeSpecification where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StructuredValue
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PriceSpecification

-- | The costs of settling the payment using a particular payment method.
--
--   [@id@] PaymentChargeSpecification
--
--   [@label@] Payment Charge Specification
--
--   [@comment@] The costs of settling the payment using a particular payment method.
--
--   [@ancestors@] @'Thing','Intangible','StructuredValue','PriceSpecification'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'PriceSpecification'@
--
--   [@url@] <http://schema.org/PaymentChargeSpecification>
data PaymentChargeSpecification = PaymentChargeSpecification { appliesToDeliveryMethod :: AppliesToDeliveryMethod
                                                             , appliesToPaymentMethod :: AppliesToPaymentMethod
                                                             , eligibleQuantity :: EligibleQuantity
                                                             , eligibleTransactionVolume :: EligibleTransactionVolume
                                                             , maxPrice :: MaxPrice
                                                             , minPrice :: MinPrice
                                                             , price :: Price
                                                             , priceCurrency :: PriceCurrency
                                                             , validFrom :: ValidFrom
                                                             , validThrough :: ValidThrough
                                                             , valueAddedTaxIncluded :: ValueAddedTaxIncluded
                                                             , additionalType :: AdditionalType
                                                             , alternateName :: AlternateName
                                                             , description :: Description
                                                             , image :: Image
                                                             , mainEntityOfPage :: MainEntityOfPage
                                                             , name :: Name
                                                             , potentialAction :: PotentialAction
                                                             , sameAs :: SameAs
                                                             , url :: Url
                                                             }
                                  deriving (Show, Read, Eq, Typeable)

instance MetaData PaymentChargeSpecification where
  _label         = const "Payment Charge Specification"
  _comment_plain = const "The costs of settling the payment using a particular payment method."
  _comment       = const "The costs of settling the payment using a particular payment method."
  _url           = const "http://schema.org/PaymentChargeSpecification"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PriceSpecification.PriceSpecification)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.PriceSpecification.PriceSpecification)]