{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ReplyAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InteractAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CommunicateAction

-- | The act of responding to a question/message asked/sent by the object. Related to AskAction.Related actions:AskAction: Appears generally as an origin of a ReplyAction.
--
--   [@id@] ReplyAction
--
--   [@label@] Reply Action
--
--   [@comment@] The act of responding to a question/message asked/sent by the object. Related to <a href=\"http://schema.org/AskAction\">AskAction</a>.<p>Related actions:</p><ul><li><a href=\"http://schema.org/AskAction\">AskAction</a>: Appears generally as an origin of a ReplyAction</li></ul>.
--
--   [@ancestors@] @'Thing','Action','InteractAction','CommunicateAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'CommunicateAction'@
--
--   [@url@] <http://schema.org/ReplyAction>
data ReplyAction = ReplyAction { resultComment :: ResultComment
                               , about :: About
                               , inLanguage :: InLanguage
                               , recipient :: Recipient
                               , actionStatus :: ActionStatus
                               , agent :: Agent
                               , endTime :: EndTime
                               , error :: Error
                               , instrument :: Instrument
                               , location :: Location
                               , object :: Object
                               , participant :: Participant
                               , result :: Result
                               , startTime :: StartTime
                               , target :: Target
                               , additionalType :: AdditionalType
                               , alternateName :: AlternateName
                               , description :: Description
                               , image :: Image
                               , mainEntityOfPage :: MainEntityOfPage
                               , name :: Name
                               , potentialAction :: PotentialAction
                               , sameAs :: SameAs
                               , url :: Url
                               }
                   deriving (Show, Read, Eq, Typeable)

instance MetaData ReplyAction where
  _label         = const "Reply Action"
  _comment_plain = const "The act of responding to a question/message asked/sent by the object. Related to AskAction.Related actions:AskAction: Appears generally as an origin of a ReplyAction."
  _comment       = const "The act of responding to a question/message asked/sent by the object. Related to <a href=\"http://schema.org/AskAction\">AskAction</a>.<p>Related actions:</p><ul><li><a href=\"http://schema.org/AskAction\">AskAction</a>: Appears generally as an origin of a ReplyAction</li></ul>."
  _url           = const "http://schema.org/ReplyAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InteractAction.InteractAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CommunicateAction.CommunicateAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CommunicateAction.CommunicateAction)]