{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.RsvpAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InteractAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CommunicateAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InformAction

-- | The act of notifying an event organizer as to whether you expect to attend the event.
--
--   [@id@] RsvpAction
--
--   [@label@] Rsvp Action
--
--   [@comment@] The act of notifying an event organizer as to whether you expect to attend the event.
--
--   [@ancestors@] @'Thing','Action','InteractAction','CommunicateAction','InformAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'InformAction'@
--
--   [@url@] <http://schema.org/RsvpAction>
data RsvpAction = RsvpAction { additionalNumberOfGuests :: AdditionalNumberOfGuests
                             , comment :: Comment
                             , rsvpResponse :: RsvpResponse
                             , event :: Event
                             , about :: About
                             , inLanguage :: InLanguage
                             , recipient :: Recipient
                             , actionStatus :: ActionStatus
                             , agent :: Agent
                             , endTime :: EndTime
                             , error :: Error
                             , instrument :: Instrument
                             , location :: Location
                             , object :: Object
                             , participant :: Participant
                             , result :: Result
                             , startTime :: StartTime
                             , target :: Target
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData RsvpAction where
  _label         = const "Rsvp Action"
  _comment_plain = const "The act of notifying an event organizer as to whether you expect to attend the event."
  _comment       = const "The act of notifying an event organizer as to whether you expect to attend the event."
  _url           = const "http://schema.org/RsvpAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InteractAction.InteractAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CommunicateAction.CommunicateAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InformAction.InformAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.InformAction.InformAction)]