{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.TherapeuticProcedure where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalProcedure
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TherapeuticProcedure
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalTherapy

-- | A medical procedure intended primarily for therapeutic purposes, aimed at improving a health condition.
--
--   [@id@] TherapeuticProcedure
--
--   [@label@] Therapeutic Procedure
--
--   [@comment@] A medical procedure intended primarily for therapeutic purposes, aimed at improving a health condition.
--
--   [@ancestors@] @'Thing','MedicalEntity','MedicalProcedure','TherapeuticProcedure','Thing','MedicalEntity','MedicalTherapy'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'MedicalProcedure','MedicalTherapy'@
--
--   [@url@] <http://schema.org/TherapeuticProcedure>
data TherapeuticProcedure = TherapeuticProcedure { adverseOutcome :: AdverseOutcome
                                                 , contraindication :: Contraindication
                                                 , duplicateTherapy :: DuplicateTherapy
                                                 , indication :: Indication
                                                 , seriousAdverseOutcome :: SeriousAdverseOutcome
                                                 , code :: Code
                                                 , guideline :: Guideline
                                                 , medicineSystem :: MedicineSystem
                                                 , recognizingAuthority :: RecognizingAuthority
                                                 , relevantSpecialty :: RelevantSpecialty
                                                 , study :: Study
                                                 , followup :: Followup
                                                 , howPerformed :: HowPerformed
                                                 , preparation :: Preparation
                                                 , procedureType :: ProcedureType
                                                 , additionalType :: AdditionalType
                                                 , alternateName :: AlternateName
                                                 , description :: Description
                                                 , image :: Image
                                                 , mainEntityOfPage :: MainEntityOfPage
                                                 , name :: Name
                                                 , potentialAction :: PotentialAction
                                                 , sameAs :: SameAs
                                                 , url :: Url
                                                 }
                            deriving (Show, Read, Eq, Typeable)

instance MetaData TherapeuticProcedure where
  _label         = const "Therapeutic Procedure"
  _comment_plain = const "A medical procedure intended primarily for therapeutic purposes, aimed at improving a health condition."
  _comment       = const "A medical procedure intended primarily for therapeutic purposes, aimed at improving a health condition."
  _url           = const "http://schema.org/TherapeuticProcedure"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalProcedure.MedicalProcedure)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TherapeuticProcedure.TherapeuticProcedure)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalTherapy.MedicalTherapy)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalProcedure.MedicalProcedure)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalTherapy.MedicalTherapy)]