{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.TradeAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BuyAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DonateAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.OrderAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PayAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.QuoteAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RentAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SellAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TipAction

-- | The act of participating in an exchange of goods and services for monetary compensation. An agent trades an object, product or service with a participant in exchange for a one time or periodic payment.
--
--   [@id@] TradeAction
--
--   [@label@] Trade Action
--
--   [@comment@] The act of participating in an exchange of goods and services for monetary compensation. An agent trades an object, product or service with a participant in exchange for a one time or periodic payment.
--
--   [@ancestors@] @'Thing','Action'@
--
--   [@subtypes@] @'BuyAction','DonateAction','OrderAction','PayAction','QuoteAction','RentAction','SellAction','TipAction'@
--
--   [@supertypes@] @'Action'@
--
--   [@url@] <http://schema.org/TradeAction>
data TradeAction = TradeAction { price :: Price
                               , priceSpecification :: PriceSpecification
                               , actionStatus :: ActionStatus
                               , agent :: Agent
                               , endTime :: EndTime
                               , error :: Error
                               , instrument :: Instrument
                               , location :: Location
                               , object :: Object
                               , participant :: Participant
                               , result :: Result
                               , startTime :: StartTime
                               , target :: Target
                               , additionalType :: AdditionalType
                               , alternateName :: AlternateName
                               , description :: Description
                               , image :: Image
                               , mainEntityOfPage :: MainEntityOfPage
                               , name :: Name
                               , potentialAction :: PotentialAction
                               , sameAs :: SameAs
                               , url :: Url
                               }
                   deriving (Show, Read, Eq, Typeable)

instance MetaData TradeAction where
  _label         = const "Trade Action"
  _comment_plain = const "The act of participating in an exchange of goods and services for monetary compensation. An agent trades an object, product or service with a participant in exchange for a one time or periodic payment."
  _comment       = const "The act of participating in an exchange of goods and services for monetary compensation. An agent trades an object, product or service with a participant in exchange for a one time or periodic payment."
  _url           = const "http://schema.org/TradeAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.BuyAction.BuyAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.DonateAction.DonateAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.OrderAction.OrderAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PayAction.PayAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.QuoteAction.QuoteAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.RentAction.RentAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SellAction.SellAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TipAction.TipAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]