{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.UnitPriceSpecification where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StructuredValue
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PriceSpecification

-- | The price asked for a given offer by the respective organization or person.
--
--   [@id@] UnitPriceSpecification
--
--   [@label@] Unit Price Specification
--
--   [@comment@] The price asked for a given offer by the respective organization or person.
--
--   [@ancestors@] @'Thing','Intangible','StructuredValue','PriceSpecification'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'PriceSpecification'@
--
--   [@url@] <http://schema.org/UnitPriceSpecification>
data UnitPriceSpecification = UnitPriceSpecification { billingIncrement :: BillingIncrement
                                                     , priceType :: PriceType
                                                     , unitCode :: UnitCode
                                                     , unitText :: UnitText
                                                     , eligibleQuantity :: EligibleQuantity
                                                     , eligibleTransactionVolume :: EligibleTransactionVolume
                                                     , maxPrice :: MaxPrice
                                                     , minPrice :: MinPrice
                                                     , price :: Price
                                                     , priceCurrency :: PriceCurrency
                                                     , validFrom :: ValidFrom
                                                     , validThrough :: ValidThrough
                                                     , valueAddedTaxIncluded :: ValueAddedTaxIncluded
                                                     , additionalType :: AdditionalType
                                                     , alternateName :: AlternateName
                                                     , description :: Description
                                                     , image :: Image
                                                     , mainEntityOfPage :: MainEntityOfPage
                                                     , name :: Name
                                                     , potentialAction :: PotentialAction
                                                     , sameAs :: SameAs
                                                     , url :: Url
                                                     }
                              deriving (Show, Read, Eq, Typeable)

instance MetaData UnitPriceSpecification where
  _label         = const "Unit Price Specification"
  _comment_plain = const "The price asked for a given offer by the respective organization or person."
  _comment       = const "The price asked for a given offer by the respective organization or person."
  _url           = const "http://schema.org/UnitPriceSpecification"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PriceSpecification.PriceSpecification)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.PriceSpecification.PriceSpecification)]