{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.WholesaleStore where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Store
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.WholesaleStore
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place

-- | A wholesale store.
--
--   [@id@] WholesaleStore
--
--   [@label@] Wholesale Store
--
--   [@comment@] A wholesale store.
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','Store','WholesaleStore','Thing','Place','LocalBusiness','Store'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Store'@
--
--   [@url@] <http://schema.org/WholesaleStore>
data WholesaleStore = WholesaleStore { branchCode :: BranchCode
                                     , currenciesAccepted :: CurrenciesAccepted
                                     , openingHours :: OpeningHours
                                     , paymentAccepted :: PaymentAccepted
                                     , priceRange :: PriceRange
                                     , additionalProperty :: AdditionalProperty
                                     , address :: Address
                                     , aggregateRating :: AggregateRating
                                     , containedInPlace :: ContainedInPlace
                                     , containsPlace :: ContainsPlace
                                     , event :: Event
                                     , faxNumber :: FaxNumber
                                     , geo :: Geo
                                     , globalLocationNumber :: GlobalLocationNumber
                                     , hasMap :: HasMap
                                     , isicV4 :: IsicV4
                                     , logo :: Logo
                                     , openingHoursSpecification :: OpeningHoursSpecification
                                     , photo :: Photo
                                     , review :: Review
                                     , telephone :: Telephone
                                     , alumni :: Alumni
                                     , areaServed :: AreaServed
                                     , award :: Award
                                     , brand :: Brand
                                     , contactPoint :: ContactPoint
                                     , department :: Department
                                     , dissolutionDate :: DissolutionDate
                                     , duns :: Duns
                                     , email :: Email
                                     , employee :: Employee
                                     , founder :: Founder
                                     , foundingDate :: FoundingDate
                                     , foundingLocation :: FoundingLocation
                                     , hasOfferCatalog :: HasOfferCatalog
                                     , hasPOS :: HasPOS
                                     , legalName :: LegalName
                                     , location :: Location
                                     , makesOffer :: MakesOffer
                                     , member :: Member
                                     , memberOf :: MemberOf
                                     , naics :: Naics
                                     , numberOfEmployees :: NumberOfEmployees
                                     , owns :: Owns
                                     , parentOrganization :: ParentOrganization
                                     , seeks :: Seeks
                                     , subOrganization :: SubOrganization
                                     , taxID :: TaxID
                                     , vatID :: VatID
                                     , additionalType :: AdditionalType
                                     , alternateName :: AlternateName
                                     , description :: Description
                                     , image :: Image
                                     , mainEntityOfPage :: MainEntityOfPage
                                     , name :: Name
                                     , potentialAction :: PotentialAction
                                     , sameAs :: SameAs
                                     , url :: Url
                                     }
                      deriving (Show, Read, Eq, Typeable)

instance MetaData WholesaleStore where
  _label         = const "Wholesale Store"
  _comment_plain = const "A wholesale store."
  _comment       = const "A wholesale store."
  _url           = const "http://schema.org/WholesaleStore"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Store.Store)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.WholesaleStore.WholesaleStore)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Store.Store)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Store.Store)]